#ifndef _C2SRESULT_API_H_
#define _C2SRESULT_API_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * ---- result ----
 */

const int RESULT_API_SUCCESS = 0;
const int RESULT_API_RESTORE_NOT_OWNED = 10; ///< IAP 에서 복구 할 게 없을 경우, 실패 아님)

/**
 * API 호출에는 성공했으나 결과값을 소유하고 있지 않을 경우, 실패 아님<br/>
 * 현재는 iOS AppStore 용으로 checkPromotePurchase() 에서 발생
 *
 * @since 4.4.1
 */
const int RESULT_API_NOT_OWNED = 10;

/**
 * 결제는 성공했으나 게임서버 이상 등으로 아직 지급이 보류된 상태. IAP 서버에서 자동으로 재지급 된다.<br/>
 * iapTransactionId 는 존재하며, 클라이언트는 트랜젝션 종료.<br/>
 * IAP.purchase(), IAP.restore(), IAP.restoreReceipt() 에서 발생
 */
const int RESULT_API_ITEM_DELIVERY_DELAYED = 11;

/**
 * 결제를 Offline에서 진행하도록 요청함.<br/>
 * 클라이언트는 트랜젝션 종료.<br/>
 * IAP.purchase() 에서 발생
 */
const int RESULT_API_ITEM_PENDING = 12;

/**
 * 이미 인증되어 있는 상태 (서버 1001) <br/>
 * AuthV4.connect() 에서 발생
 */
const int RESULT_API_AUTHORIZED = 20;

const int RESULT_API_INVALID_PARAM = -1;
const int RESULT_API_NOT_SUPPORTED = -2;
const int RESULT_API_IN_PROGRESS = -3;
const int RESULT_API_TIMEOUT = -4;
const int RESULT_API_NETWORK = -5;
const int RESULT_API_CANCELED = -6;
const int RESULT_API_NEED_INITIALIZE = -7;
const int RESULT_API_RESPONSE_FAIL = -8;
const int RESULT_API_INVALID_SESSION = -9;
const int RESULT_API_NEED_RESTORE = -10;

/**
 * 다른 플레이어와 인증되어 있는 상태 (서버 1002) <br/>
 * AuthV4.connect() 에서 발생
 */
const int RESULT_API_CONFLICT_PLAYER = -11;

/**
 * 제재 상태의 유저 <br/>
 * AuthV4.signIn(), AuthV4.checkBlacklist() 에서 발생
 */
const int RESULT_API_BLACKLIST = -12;

/**
 * 프로모션 코드용 마켓PID에 대한 활성화된 HIVE IAP상품이 하나도 없거나<br/>
 * 여러개 활성화 되어있을 경우 등 백오피스 설정이 잘못 되어있는 상태<br/>
 * IAP.purchase(), IAP.restore(), IAP.restoreReceipt() 에서 발생
 */
const int RESULT_API_DEVELOPER_ERROR = -13;

/**
 * 동일한 프로모션의 프로모션 코드를 중복 사용하였을 경우<br/>
 * IAP.purchase(), IAP.restore(), IAP.restoreReceipt() 에서 발생
 */
const int RESULT_API_DUPLICATED_PROMOTION_CODE = -14;

const int RESULT_API_PLAYER_CHANGE	= -15;

const int RESULT_API_UNDEFINED = -98;
const int RESULT_API_UNKNOWN = -99;


/**
 * ---- errorCode ----
 */

const int Success = 0;    // Success.
const int RefundUser = 2300;     // Refund User
const int CommonHTTPConnectionException = -1;    // [Common] HTTP Connection exception.
const int CommonHTTPConnectionOpenException = -2;    // [Common] HTTP Connection open exception.
const int CommonHTTPContentEncodingNotSupported = -3;    // [Common] HTTP Content encoding not supported.
const int CommonHTTPDecryptionFailed = -4;    // [Common] HTTP Decryption failed.
const int CommonHTTPResponseException = -5;    // [Common] HTTP Response exception.
const int CommonHTTPInvalidBody = -6;    // [Common] HTTP body is nil.
const int CommonHTTPInvalidJSON = -7;    // [Common] HTTP body has invalid JSON: %s
const int CommonHTTPInvalidURLRequest = -8;    // [Common] HTTP Failed to create NSMutableURLRequest.
const int CommonHTTPInvalidURL = -9;    // [Common] HTTP Failed to create NSURL from urlPath: %s
const int CommonHTTPGzipDecodeFailed = -10;    // [Common] GZip decoding is failed.
const int CommonHTTPNetworkError = -11;    // [Common] Network error is occurred on handle response: %s
const int TestError = -800;    // [Test] Error message.
const int TestWithNSError = -801;    // [Test] NSError message: %s
const int TestWithNSString = -802;    // [Test] NSString message: %s
const int TestWithNSDictionary = -803;    // [Test] NSDictionary message: %s
const int CommonUnknown = -999;    // [Common] Unknown
const int AuthNotInitialized = -1100001;    // [Auth-Common] Not Initialized
const int AuthInvalidServerResponse = -1100002;    // [Auth-Common] Invalid Server Response
const int AuthServerResponseNotSuccessful = -1100003;    // [Auth-Common] Server Response Not Successful. string: %s
const int AuthInvalidUser = -1100004;    // [Auth-Common] Invalid User
const int AuthUserCanceled = -1100005;    // [Auth-Common] User Canceled
const int AuthInProgressLoginLogout = -1100006;    // [Auth-Common] Login or logout is already in progress
const int AuthInvalidSelectedAccountURL = -1100007;    // [Auth-Common] Invalid Selected AccountURL
const int AuthInvalidSelectedVID = -1100008;    // [Auth-Common] Selected VID is empty or null
const int AuthOnRunningV4 = -1100009;    // [Auth-Common] On Running V4
const int AuthInvalidConfigurationXml = -1100010;    // [Auth-Common] Invalid Configuration Xml
const int AuthInvalidParamLoginType = -1100011;    // [Auth-Common] Invalid Param Login Type: %s
const int AuthInvalidParamVID = -1100012;    // [Auth-Common] Invalid Param Vid: %s
const int AuthInvalidParamSessionKey = -1100013;    // [Auth-Common] Invalid Param Session Key
const int AuthInvalidGuestSession = -1100014;    // [Auth-Common] Invalid Guest Session
const int AuthUserInBlacklist = -1100015;    // [Auth-Common] User In Blacklist: %s
const int AuthInvalidAccountSession = -1100016;    // [Auth-Common] Invalid Account Session
const int AuthJsonException = -1100017;    // [Auth-Common] JSON Parsing failed. error: %s
const int AuthCanceled = -1100018;    // [Auth-Common] Canceled
const int AuthDialogAlreadyUsing = -1100019;    // [Auth-Common] Dialog is already using.
const int AuthNetworkErrorShowLoginSelection = -1100020;    // [Auth-Common] Network error occured on Get My Profile: %s
const int AuthNetworkErrorCheckMaintenance = -1100021;    // [Auth-Common] Network error occured on Check Maintenance
const int AuthResponseFailCheckMaintenance = -1100022;    // [Auth-Common] Bad response on Check Maintenance: %s
const int AuthResponseFailMaintenanceDialog = -1100023;    // [Auth-Common] Failed to show maintenance dialog.
const int AuthNetworkErrorProcessLoginType = -1100024;    // [Auth-Common] Network error occured on Prelogin: %s
const int AuthNetworkErrorGuestLogin = -1100025;    // [Auth-Common] Network error occured on Guest Login: %s
const int AuthHIVESocialLoginCancelled = -1100026;    // [Auth-Common] HIVE social login canceled.
const int AuthNetworkErrorLoginCenterLogin = -1100027;    // [Auth-Common] Network error occured on Login Center Login: %s
const int AuthNetworkErrorRequestUpdate = -1100028;    // [Auth-Common] Network error occured on Request Update: %s
const int AuthNetworkErrorRequestAdultConfirm = -1100029;    // [Auth-Common] Network error occured on Adult Confirm.
const int AuthInvalidParamVIDList = -1100030;    // [Auth-Common] VID list is nil or empty
const int AuthAgreementFail_DoExit = -1100031;    // [Auth-Common] Agreement Fail
const int AuthMaintenanceActionDefault_DoExit = -1100032;    // [Auth-Common] Maintenance Dialog Dismiss with unknown action.
const int AuthMaintenanceActionOpenURL_DoExit = -1100033;    // [Auth-Common] Maintenance Dialog Dismiss with Open URL Button Selected.
const int AuthMaintenanceActionExit_DoExit = -1100034;    // [Auth-Common] Maintenance Dialog Dismiss with Exit Button Selected.
const int AuthMaintenanceActionDone = -1100035;    // [Auth-Common] Maintenance Dialog Dismiss with Done Button Selected.
const int AuthMaintenanceTimeover_DoExit = -1100036;    // [Auth-Common] Maintenance Dialog Dismiss with Timeover.
const int AuthUserInBlacklistActionDefault_DoExit = -1100037;    // [Auth-Common] Blacklist Dialog Dismiss with unknown action.
const int AuthUserInBlacklistActionOpenURL_DoExit = -1100038;    // [Auth-Common] Blacklist Dialog Dismiss with Open URL Button Selected.
const int AuthUserInBlacklistActionExit_DoExit = -1100039;    // [Auth-Common] Blacklist Dialog Dismiss with Exit Button Selected.
const int AuthUserInBlacklistActionDone = -1100040;    // [Auth-Common] Blacklist Dialog Dismiss with Done Button Selected.
const int AuthUserInBlacklistTimeover_DoExit = -1100041;    // [Auth-Common] Blacklist Dialog Dismiss with Timeover.
const int AuthInProgressInitialize = -1100042;    // [Auth-Common] Initialize is already in progress.
const int AuthSkipPermissionView = -1100043;    // [Auth-Common] Can skip the Permission view.
const int AuthInProgressRequestPermissionViewData = -1100044;    // [Auth-Common] Requesting PermissionViewData is already in progress.
const int AuthNetworkErrorRequestPermissionViewData = -1100045;    // [Auth-Common] Network error occjured on requestPermissionViewData
const int AuthProviderMissingKey = -1100046;        // [Auth-Common] Missing Key (%s)
const int AuthResponseFailLogoutOnlyPGSConnectedUser = -1100047;        // Logout response fail because hive user only connected PGS playerId with uid
const int AuthV4InvalidServerResponse = -1200001;    // [AuthV4-Common] InvalidServerResponse
const int AuthV4OnRunningV1 = -1200002;    // [AuthV4-Common] On running AuthV1
const int AuthV4InProgressSignIn = -1200003;    // [AuthV4-Common] SigninInProgress
const int AuthV4InvalidConfigurationXml = -1200004;    // [AuthV4-Common] Invalid configuration xml
const int AuthV4InvalidSavedPlayerInfo = -1200005;    // [AuthV4-Common] InvalidSavedPlayerInfo
const int AuthV4AlreadyAuthorized = -1200006;    // [AuthV4-Common] Already authorized: %s
const int AuthV4ConflictPlayer = -1200007;    // [AuthV4-Common] Conflict player
const int AuthV4UserInBlacklist = -1200008;    // [AuthV4-Common] User in blacklist
const int AuthV4InvalidSession = -1200009;    // [AuthV4-Common] Invalid session: %s
const int AuthV4ConflictPlayerHandlingFail = -1200010;    // [AuthV4-Common] ConflictPlayerHandlingFail
const int AuthV4InvalidParamDid = -1200011;    // [AuthV4-Common] Failed to seup. Empty DID.
const int AuthV4NotInitialized = -1200012;    // [AuthV4-Common] Setup HIVE module first.
const int AuthV4SessionExist = -1200013;    // [AuthV4-Common] Already authorized
const int AuthV4SessionNotExist = -1200014;    // [AuthV4-Common] Not exist remain session. Please sign in provider.
const int AuthV4InvalidProviderType = -1200015;    // [AuthV4-Common] Invalid provider type : %s
const int AuthV4SigninFirst = -1200016;    // [AuthV4-Common] Need Sign in first.
const int AuthV4ProviderAlreadyConnected = -1200017;    // [AuthV4-Common] Provider already connected: %s
const int AuthV4ProviderAlreadyDisconnected = -1200018;    // [AuthV4-Common] Provider already disconnected: %s
const int AuthV4InvalidParamSelectedPlayerid = -1200019;    // [AuthV4-Common] InvalidParamSelectedPlayerid
const int AuthV4InvalidConflictInfo = -1200020;    // [AuthV4-Common] Invalid conficlt info : %s
const int AuthV4InvalidPlayeridList = -1200021;    // [AuthV4-Common] Empty playerID List
const int AuthV4JsonException = -1200022;    // [AuthV4-Common] JsonException : %s
const int AuthV4InvalidSigninSelection = -1200023;    // [AuthV4-Common] Invalid signin selection
const int AuthV4NotSupportedProviderType = -1200024;    // [AuthV4-Common] Not supported requested provider type : %s
const int AuthV4WebviewDialogError = -1200025;    // [AuthV4-Common] Webview dialog error: %s
const int AuthV4InProgressAuthDialog = -1200026;    // [AuthV4-Common] Dialog already used.
const int AuthV4InvalidParamViewID = -1200027;    // [AuthV4-Common] Empty View ID.
const int AuthV4InvalidParamPlayerID = -1200028;    // [AuthV4-Common] Invalid player ID: %s
const int AuthV4NetworkErrorSigninGuest = -1200029;    // [AuthV4-Common] Network error occured on Internal Signin Guest. type: %s
const int AuthV4ResponseFailProviderUserID = -1200030;    // [AuthV4-Common] Response error. Provider user ID is empty.
const int AuthV4ResponseFailSelectedPlayerID = -1200031;    // [AuthV4-Common] Response error. Selected player ID is empty or nil
const int AuthV4CancelDialog = -1200032;    // [AuthV4-Common] Dialog canceled by user.
const int AuthV4ResponseFailSocialDialog = -1200033;    // [AuthV4-Common] Response error. Social Dialog.: %s
const int AuthV4ProfileNetworkError = -1200034;    // [AuthV4-Profile] Network error is occurred.
const int AuthV4ProfileResponseFail = -1200035;    // [AuthV4-Profile] Response Fail.
const int AuthV4MembershipNetworkError = -1200036;    // [AuthV4-Membership] Network error is occurred.
const int AuthV4MembershipResponseFail = -1200037;    // [AuthV4-Membership] Response Fail.
const int AuthV4ResponseFailSigninProvider = -1200038;    // [AuthV4-Common] Response Fail on Internal Signin Provider : %s
const int AuthV4ResponseFailCheckProvider = -1200039;    // [AuthV4-Common] Response Fail on CheckProvider : %s
const int AuthV4ResponseFailGetFriendList = -1200040;    // [AuthV4-Common] Response Fail on GetFriendList : %s
const int AuthV4ResponseFailSigninGuest = -1200041;    // [AuthV4-Common] Response Fail on SigninGuest : %s
const int AuthV4InProgressConnect = -1200042;    // [AuthV4-Common] Connection is already in progress
const int AuthV4InProgressShowLeaderboard = -1200043;    // [AuthV4-Common] Showing leaderboard is already in progress
const int AuthV4InProgressShowAchievements = -1200044;    // [AuthV4-Common] Showing achievements is already in progress
const int AuthV4PlayerChange = -1200045;    // [AuthV4-Common] Success, but account is switched to device account.
const int AuthV4HelperImplifiedLoginFail = -1200046;    // [AuthV4Helper-Common] Implified login failed.
const int AuthV4PlayerResolved = -1200047;    // [AuthV4Helper-Common] Player resolved.
const int AuthV4AgreementFail_DoExit = -1200048;    // [AuthV4-Common] Agreement Fail
const int AuthV4AgreementFailWithWebviewError_DoExit = -1200049;    // [AuthV4-Common] Agreement Fail with Webview Error
const int AuthV4MaintenanceActionDefault_DoExit = -1200050;    // [AuthV4-Common] Maintenance Dialog Dismiss with unknown reason
const int AuthV4MaintenanceActionOpenURL_DoExit = -1200051;    // [AuthV4-Common] Maintenance Dialog Dismiss with OpenURL button selected
const int AuthV4MaintenanceActionExit_DoExit = -1200052;    // [AuthV4-Common] Maintenance Dialog Dismiss with Exit button selected
const int AuthV4MaintenanceActionDone = -1200053;    // [AuthV4-Common] Maintenance Dialog Dismiss with Done button selected
const int AuthV4MaintenanceTimeover_DoExit = -1200054;    // [AuthV4-Common] Maintenance Dialog Dismiss with Timeover
const int AuthV4NetworkError = -1200055;    // [AuthV4-Common] Network error occured : %s
const int AuthV4InvalidResponseData = -1200056;    // [AuthV4-Common] Invalid response data : %s
const int AuthV4ServerResponseError = -1200057;    // [AuthV4-Common] Server response error : %s
const int AuthV4NeedSignIn = -1200058;    // [AuthV4-Common] Need sign in.
const int AuthV4InProgress = -1200059;    // [AuthV4-Common] In progress.
const int AuthV4InvalidParam = -1200060;    // [AuthV4-Common] Invalid param : %s
const int AuthV4SkipPermissionView = -1200061;    // [AuthV4-Common] Can skip the Permission view.
const int AuthV4InvalidCertification =  -1200062; // [AuthV4-Common] Invalid HiveCertification.
const int AuthV4ProviderLoginError = -1200101;    // [AuthV4-Provider] ProviderLoginError
const int AuthV4ProviderLogoutError = -1200102;    // [AuthV4-Provider] Logout Failed
const int AuthV4ProviderNotSupportGetFriends = -1200103;    // [AuthV4-Provider] Not supported function.
const int AuthV4ProviderLoginCancel = -1200104;    // [AuthV4-Provider] Provider Login canceled.
const int AuthV4FacebookUserCanceled = -1200201;    // [AuthV4-ProviderFacebook] Login action canceled by user.
const int AuthV4FacebookResponseFailGetFriends = -1200202;    // [AuthV4-ProviderFacebook] Response error : %s
const int AuthV4FacebookNetworkErrorUploadProfile = -1200203;    // [AuthV4-ProviderFacebook] Network error occured on upload profile.
const int AuthV4FacebookResponseFailUploadProfile = -1200204;    // [AuthV4-ProviderFacebook] Response error. Failed to upload profile.
const int AuthV4ProviderMissingKey = -1200105; // [AuthV4-Provider] Missing Key (%s)
const int authV4ProviderNotSupportedMyInquiry = -1200106; // [AuthV4-Provider] Not supported MyInquiry.
const int AuthV4FacebookResponseError = -1200205;    // [AuthV4-ProviderFacebook] Response error : %s
const int AuthV4FacebookInvalidResponseData = -1200206;    // [AuthV4-ProviderFacebook] Invalid response data : %s
const int AuthV4FacebookNetworkError = -1200207;    // [AuthV4-ProviderFacebook] Network error occured : %s
const int AuthV4FacebookCancel = -1200208;    // [AuthV4-ProviderFacebook] Login canceled
const int AuthV4GoogleResponseFailLogin = -1200301;    // [AuthV4-ProviderGoogle] Connection failed
const int AuthV4GoogleResponseFailLogout = -1200302;    // [AuthV4-ProviderGoogle] DisconnetionFailed
const int AuthV4GoogleNetworkErrorUploadProfile = -1200303;    // [AuthV4-ProviderGoogle] Network error is occured on upload profile.
const int AuthV4GoogleResponseFailUploadProfile = -1200304;    // [AuthV4-ProviderGoogle] Response error. Failed to upload profile.
const int AuthV4GoogleResponseFailShowAchievements = -1200305;    // [AuthV4-ProviderGoogle] Response error. Failed to show achievements.
const int AuthV4GoogleResponseFailShowLeaderboards = -1200306;    // [AuthV4-ProviderGoogle] Response error. Failed to show leaderboards.
const int AuthV4GoogleNotSupported = -1200307;    // [AuthV4-ProviderGoogle] Provider google is not supported.
const int AuthV4GoogleLoginCancel = -1200308;    // [AuthV4-ProviderGoogle] Google Login canceled.
const int AuthV4GoogleNetworkError = -1200309;    // [AuthV4-ProviderGoogle] Network Error
const int AuthV4GoogleLogout = -1200310;    // [AuthV4-ProviderGoogle] Logout.
const int AuthV4GoogleResponseFailAchievementsReveal = -1200311;    // [AuthV4-ProviderGoogle] Failed to achievements reveal.
const int AuthV4GoogleResponseFailAchievementsUnlock = -1200312;    // [AuthV4-ProviderGoogle] Failed to achievements unlock.
const int AuthV4GoogleResponseFailAchievementsIncrement = -1200313;    // [AuthV4-ProviderGoogle] Failed to achievements increment.
const int AuthV4GoogleResponseFailLeaderboardsSubmitScore = -1200314;    // [AuthV4-ProviderGoogle] Failed to leaderboards submit score.
const int AuthV4GoogleNeedSignIn = -1200315;    // [AuthV4-ProviderGoogle] Need ProviderGoogle sign in
const int AuthV4GoogleNeedSettingOption                    =  -1200316; // [AuthV4-ProviderGoogle] Need setting option.
const int AuthV4GoogleResponseFailPGSGetServerAccessToken  =  -1200317; // [AuthV4-ProviderGoogle] Failed to get PGS Server Access Token.
const int AuthV4GoogleResponseFailPGSGetPlayerId           =  -1200318; // [AuthV4-ProviderGoogle] Failed to get PGS Player Id.
const int AuthV4GoogleObjectNotReady                       =  -1200319; // [AuthV4-ProviderGoogle] Google object not ready.
const int AuthV4AppleLoginCancel = -1200401;    // [AuthV4-ProviderApple] Login canceled
const int AuthV4AppleResponseFailLogin = -1200402;    // [AuthV4-ProviderApple] Response error. login: %s
const int AuthV4AppleTimeOut = -1200403;    // [AuthV4-ProviderApple] Timeout
const int AuthV4AppleResponseFailReportScore = -1200404;    // [AuthV4-ProviderApple] Response error. Failed to report score: %s
const int AuthV4AppleInProgressGameCenterVC = -1200405;    // [AuthV4-ProviderApple] GameCenterViewController in use.
const int AuthV4AppleResponseFailLoadAchievements = -1200406;    // [AuthV4-ProviderApple] Response error. Load achievements failed: %s
const int AuthV4AppleResponseFailReportAchievements = -1200407;    // [AuthV4-ProviderApple] Response error. Report achievements failed: %s
const int AuthV4AppleResponseFailResetAchievements = -1200408;    // [AuthV4-ProviderApple] Response error. Reset achievements failed: %s
const int AuthV4AppleNotSupported = -1200409;    // [AuthV4-ProviderApple] Provider apple is not supported.
const int AuthV4AppleInProgress = -1200410;    // [AuthV4-ProviderApple] In Progress
const int AuthV4AppleResponseError = -1200411;    // [AuthV4-ProviderApple] Response error : %s
const int AuthV4AppleCancel = -1200412;    // [AuthV4-ProviderApple] Canceled
const int AuthV4VKResponseFailLogin = -1200501;    // [AuthV4-ProviderVK] Response Fail on request login : %s
const int AuthV4VKInvalidParamSDK = -1200502;    // [AuthV4-ProviderVK] VK SDK setup failed.
const int AuthV4VKNotInitialized = -1200503;    // [AuthV4-ProviderVK] VK SDK not initialized.
const int AuthV4VKCancelLogin = -1200504;    // [AuthV4-ProviderVK] Request authorization is canceled
const int AuthV4VKInvalidSession = -1200505;    // [AuthV4-ProviderVK] Invalid VK session.
const int AuthV4VKResponseFailGetFriends = -1200506;    // [AuthV4-ProviderVK] Response Fail on get friends: %s
const int AuthV4VKResponseFailLogout = -1200507;    // [AuthV4-ProviderVK] Response Fail on request logout.
const int AuthV4VKResponseFailUploadProfile = -1200508;    // [AuthV4-ProviderVK] Response Fail
const int AuthV4VKNetworkErrorUploadProfile = -1200509;    // [AuthV4-ProviderVK] Network error occured : %s
const int AuthV4VKInProgress = -1200510;    // [AuthV4-ProviderVK] In progress
const int AuthV4VKResponseError = -1200511;    // [AuthV4-ProviderVK] Response error : %s
const int AuthV4VKNetworkError = -1200512;    // [AuthV4-ProviderVK] Network error occured : %s
const int AuthV4VKInvalidParam = -1200513;    // [AuthV4-ProviderVK] Invalid param : %s
const int AuthV4VKCancel = -1200514;    // [AuthV4-ProviderVK] Canceled
const int AuthV4VKTokenResponseError = -1200515;    // [AuthV4-ProviderVK] Token Response Error : %s
const int AuthV4WechatInProgressLoginLogout = -1200601;    // [AuthV4-ProviderWeChat] Login or logout in progress.
const int AuthV4WechatResponseFailLogin = -1200602;    // [AuthV4-ProviderWeChat] Response error. Failed to login: %s
const int AuthV4WechatNotSupportedRequest = -1200603;    // [AuthV4-ProviderWeChat] Request is not supported: %s
const int AuthV4WechatResponseFailUserInfo = -1200604;    // [AuthV4-ProviderWeChat] Request error. failed to get user info: %s
const int AuthV4WechatNetworkErrorUserInfo = -1200605;    // [AuthV4-ProviderWeChat] Request error. NetworkError while getting user info: %s
const int AuthV4WechatNetworkError = -1200606;    // [AuthV4-ProviderWeChat] Network error occured : %s
const int AuthV4WechatResponseFail = -1200607;    // [AuthV4-ProviderWeChat] Response fail : %s
const int AuthV4WechatNetworkErrorLogin = -1200608;    // [AuthV4-ProviderWeChat] NetworkError. Failed to login.
const int AuthV4WechatLoginCancel = -1200609;    // [AuthV4-ProviderWeChat] Login canceled.
const int AuthV4WechatInProgress = -1200610;    // [AuthV4-ProviderWeChat] In progress
const int AuthV4WechatResponseError = -1200611;    // [AuthV4-ProviderWeChat] Response Error : %s
const int AuthV4WechatInvalidResponseData = -1200612;    // [AuthV4-ProviderWeChat] Invalid Response Data : %s
const int AuthV4WechatInvalidAppKey = -1200613;    // [AuthV4-ProviderWeChat] Invalid App Key : %s
const int AuthV4HIVEDialogCancel = -1200701;    // [AuthV4-ProviderHIVE] Dialog is canceled
const int AuthV4HIVENetworkErrorUploadProfile = -1200702;    // [AuthV4-ProviderHIVE] Network error is occured on upload profile.
const int AuthV4HIVEResponseFailUploadProfile = -1200703;    // [AuthV4-ProviderHIVE] Response error. failed to upload profile.
const int AuthV4HIVEInProgress = -1200704;    // [AuthV4-ProviderHIVE] In progress
const int AuthV4HIVEResponseError = -1200705;    // [AuthV4-ProviderHIVE] Response error : %s
const int AuthV4HIVENetworkError = -1200706;    // [AuthV4-ProviderHIVE] Network Error
const int AuthV4HIVEInvalidParam = -1200707;    // [AuthV4-ProviderHIVE] Invalid param : %s
const int AuthV4HIVECancel = -1200708;    // [AuthV4-ProviderHIVE] Cancel
const int AuthV4QQInProgressLoginLogout = -1200801;    // [AuthV4-ProviderQQ] Login or logout in progress.
const int AuthV4QQResponseFailLogin = -1200802;    // [AuthV4-ProviderQQ] Invalid login session.
const int AuthV4QQCancelLogin = -1200803;    // [AuthV4-ProviderQQ] login is canceled.
const int AuthV4QQNetworkError = -1200804;    // [AuthV4-ProviderQQ] Network error occurred.
const int AuthV4QQNetworkErrorUploadProfile = -1200805;    // [AuthV4-ProviderQQ] Network error is occurred on upload profile
const int AuthV4QQResponseFailUploadProfile = -1200806;    // [AuthV4-ProviderQQ] Response error. Failed to upload profile
const int AuthV4QQCancelUploadProfile = -1200807;    // [AuthV4-ProviderQQ] Upload profiel is canceled.
const int AuthV4QQResponseFailLogout = -1200808;    // [AuthV4-ProviderQQ] Response error. Failed to logout.
const int AuthV4QQNotInitialized = -1200809;    // [AuthV4-ProviderQQ] QQ SDK not initialized.
const int AuthV4QQInProgress = -1200810;    // [AuthV4-ProviderQQ] In progress
const int AuthV4QQResponseError = -1200811;    // [AuthV4-ProviderQQ] Response error
const int AuthV4QQInvalidResponseData = -1200812;    // [AuthV4-ProviderQQ] Invalid response data : %s
const int AuthV4QQInvalidParam = -1200813;    // [AuthV4-ProviderQQ] Invalid param : %s
const int AuthV4QQCancel = -1200814;    // [AuthV4-ProviderQQ] Cancel
const int AuthV4SignInAppleUnknown = -1200901;    // [AuthV4-ProviderSignInApple] Unknown
const int AuthV4SignInAppleCanceled = -1200902;    // [AuthV4-ProviderSignInApple] Canceled
const int AuthV4SignInAppleFailed = -1200903;    // [AuthV4-ProviderSignInApple] Failed
const int AuthV4SignInAppleInvalidResponse = -1200904;    // [AuthV4-ProviderSignInApple] Invalid Response
const int AuthV4SignInAppleNotHandled = -1200905;    // [AuthV4-ProviderSignInApple] Not Handled
const int AuthV4SignInAppleNotSupported = -1200906;    // [AuthV4-ProviderSignInApple] Not Supported
const int AuthV4LineInvalidParam = -1201001;    // [AuthV4-ProviderLine] Invalid Param
const int AuthV4LineCancel = -1201002;    // [AuthV4-ProviderLine] Cancel
const int AuthV4LineResponseError = -1201003;    // [AuthV4-ProviderLine] Response Error
const int AuthV4LineNetworkError = -1201004;    // [AuthV4-ProviderLine] Network Error
const int AuthV4TwitterResponseError = -1201101;    // [AuthV4-ProviderTwitter] Response Error
const int AuthV4TwitterInvalidParam = -1201102;    // [AuthV4-ProviderTwitter] Invalid Param
const int AuthV4WeverseInProgressLoginLogout               =  -1201201; // [AuthV4-ProviderWeverse] Login or logout in progress.
const int AuthV4WeverseResponseFailLogin                   =  -1201202; // [AuthV4-ProviderWeverse] Response error. Failed to login: %s
const int AuthV4WeverseNotSupported                        =  -1201203; // [AuthV4-ProviderWeverse] Not supported: %s
const int AuthV4WeverseNetworkError                        =  -1201204; // [AuthV4-ProviderWeverse] Network error occured : %s
const int AuthV4WeverseLoginCancel                         =  -1201205; // [AuthV4-ProviderWeverse] Login canceled.
const int AuthV4WeverseResponseError                       =  -1201206; // [AuthV4-ProviderWeverse] Response Error : %s
const int AuthV4NotRegisteredDevice                        =  -1201300; // [AuthV4-DeviceManagement] Not Registered Device.
const int SocialResponseFailDismissDialog = -2000001;    // [Social-Common] InvalidParamClose
const int SocialCancelDismissDialog = -2000002;    // [Social-Common] Canceled
const int SocialCancelConnect                              =  -2000003; // [Social-Common] Canceled social connect.
const int SocialResponseFailConnect                        =  -2000004; // [Social-Common] Fail to connect to social.
const int SocialCancelGetPictureFromGallery                =  -2000005; // [Social-Common] Canceled to get picture from gallery.
const int SocialResponseFailGetPictureFromGallery          =  -2000006; // [Social-Common] Failed to get picture from gallery.
const int SocialCancelSharePhoto                           =  -2000007; // [Social-Common] Canceled to share photo.
const int SocialResponseFailSharePhoto                     =  -2000008; // [Social-Common] Failed to share photo.
const int SocialInvalidParam                               =  -2000009; // [Social-Common] Invalid param : %s
const int SocialProviderNotInitialized                     =  -2000010; // [Social-Common] Social Provider Not Initialized.
const int SocialGoogleNotInitialized = -2000101;    // [Social-Google] Not initialized. initialize user first.
const int SocialGoogleResponseFailGetProfile = -2000102;    // [Social-Google] Fail to get profile. check response
const int SocialGoogleInProgressConnect = -2000103;    // [Social-Google] In progress. connect.
const int SocialGoogleResponseFailConnect = -2000104;    // [Social-Google] Response error. Failed to connect.
const int SocialGoogleCancelGetProfile = -2000105;    // [Social-Google] Get profile is canceled.
const int SocialGoogleCancelConnect = -2000106;    // [Social-Google] Connect is canceled.
const int SocialGoogleNetworkErrorUpdateServerFlag = -2000107;    // [Social-Google] Network error is occured on update server flag.
const int SocialGoogleResponseFailUpdateServerFlag = -2000108;    // [Social-Google] Response error. Failed to update server flag.
const int SocialFacebookNotInitialized = -2000201;    // [Social-Facebook] Not initialized. initialize user first.
const int SocialFacebookResponseFailGetProfile = -2000202;    // [Social-Facebook] Fail to get profile. check response: %s
const int SocialFacebookCancelGetProfile = -2000203;    // [Social-Facebook] Get profile canceled.
const int SocialFacebookResponseFailGetFriends = -2000204;    // [Social-Facebook] Fail to get friends. check response: %s
const int SocialFacebookCancelGetFriends = -2000205;    // [Social-Facebook] Get friends canceled.
const int SocialFacebookResponseFailSendMessage = -2000206;    // [Social-Facebook] Fail to send message. check response: %s
const int SocialFacebookCancelSendMessage = -2000207;    // [Social-Facebook] Send message canceled.
const int SocialFacebookMessageDialogShowFail = -2000208;    // [Social-Facebook] Fail to show message dialog.
const int SocialFacebookResponseFailShowInvitation = -2000209;    // [Social-Facebook] Fail to show invite dialog: %s
const int SocialFacebookCancelShowInvitation = -2000210;    // [Social-Facebook] Show invite dialog canceled
const int SocialFacebookInvalidParamPost = -2000211;    // [Social-Facebook] Invalid paramter for posting to facebook.
const int SocialFacebookPostDialogShowFail = -2000212;    // [Social-Facebook] Fail to show post dialog.
const int SocialFacebookShareFail = -2000213;    // [Social-Facebook] Fail to share: %s
const int SocialFacebookShareCancelled = -2000214;    // [Social-Facebook] Sharing canceled.
const int SocialFacebookSendInvitationFail = -2000215;    // [Social-Facebook] Fail to send invitation: %s
const int SocialFacebookSendInvitationCancelled = -2000216;    // [Social-Facebook] Send invitation is canceled.
const int SocialFacebookCancelPost = -2000217;    // [Social-Facebook] Posting is canceled.
const int SocialFacebookResponseFailPost = -2000218;    // [Social-Facebook] Response error. Failed to posting.
const int SocialFacebookOperationException = -2000219;    // [Social-Facebook] Operation exception is occured.
const int SocialFacebookServiceException = -2000220;    // [Social-Facebook] Service exception is occured.
const int SocialFacebookException = -2000221;    // [Social-Facebook] Exception is occured.
const int SocialHIVENotInitialized = -2000301;    // [Social-HIVE] Not initialized. initialize user first.
const int SocialHIVENetworkErrorGetMyProfile = -2000302;    // [Social-HIVE] Network error occured on Get My Profile: %s
const int SocialHIVEInvalidParamSetMyProfile = -2000303;    // [Social-HIVE] Invalid parameter. Comment is required
const int SocialHIVENetworkErrorSetMyProfile = -2000304;    // [Social-HIVE] Network error occured on Set My Profile: %s
const int SocialHIVENetworkErrorGetFriends = -2000305;    // [Social-HIVE] Network error occured on Get Friends: %s
const int SocialHIVEInvalidSession = -2000306;    // [Social-HIVE] Invalid session. Only HIVE user is permitted
const int SocialHIVEInvalidParamVID = -2000307;    // [Social-HIVE] Invalid parameter. Valid VID is required.
const int SocialHIVENetworkErrorGetVIDByUIDList = -2000308;    // [Social-HIVE] Network error occured on Get VID By UID List: %s
const int SocialHIVENetworkErrorGetUIDByVIDList = -2000309;    // [Social-HIVE] Network error occured on Get UID By VID List: %s
const int SocialHIVEInvalidParamContentSendMessage = -2000310;    // [Social-HIVE] Invalid parameter. Message content is required.
const int SocialHIVENetworkErrorSendMessage = -2000311;    // [Social-HIVE] Network error occured on Send Message: %s
const int SocialHIVEInvalidParamReceiptSendMessage = -2000312;    // [Social-HIVE] Invalid parameter. Need valid receipts for Send Message.
const int SocialHIVEInvalidParamUID = -2000313;    // [Social-HIVE] Invalid parameter. UID is empty or nil
const int SocialHIVEInProgressSocialDialog = -2000314;    // [Social-HIVE] In progress. SocialDialog is already showing.
const int SocialHIVESocialDialogClosed = -2000315;    // [Social-HIVE] SocialDialog is closed.
const int SocialHIVENetworkErrorGetBadgeInfo = -2000316;    // [Social-HIVE] Network error occured on Get Badge Info: %s
const int SocialHIVEResponseFailGetMyProfile = -2000317;    // [Social-HIVE] Response error is occured on Get My Profile: %s
const int SocialHIVEResponseFailSetMyProfile = -2000318;    // [Social-HIVE] Response error is occured on Set My Profile: %s
const int SocialHIVEResponseFailGetFriends = -2000319;    // [Social-HIVE] Response error is occured on Get Friends: %s
const int SocialHIVEResponseFailGetVID = -2000320;    // [Social-HIVE] Response error occured on Get VID: %s
const int SocialHIVEResponseFailInvalidVIDList = -2000321;    // [Social-HIVE] Server response vid list does not match.
const int SocialHIVEResponseFailGetUID = -2000322;    // [Social-HIVE] Response error occured on Get UID: %s
const int SocialHIVEResponseFailInvalidUIDList = -2000323;    // [Social-HIVE] Server response uid list does not match.
const int SocialHIVEResponseFailSendMessage = -2000324;    // [Social-HIVE] Response error is occured on Send Message: %s
const int SocialHIVEResponseFailGetBadgeInfo = -2000325;    // [Social-HIVE] Response error is occured on Get badge: %s
const int SocialHIVEResponseFailDialogWebView = -2000326;    // [Social-HIVE] WebView error is occured in social dialog: %s
const int SocialHIVEResponseFailSocialDialog = -2000327;    // [Social-HIVE] Social dialog error is occured.
const int SocialHIVEInvalidParamFriendType = -2000328;    // [Social-HIVE] Requested friend type %s is not supported.
const int SocialHIVEResponseFailGetProfiles = -2000329;    // [Social-HIVE] Response error. Failed to get profiles.
const int SocialHIVEInvalidParamGetProfiles = -2000330;    // [Social-HIVE] Invalid param get profiles.
const int SocialHIVEResponseFail = -2000331;    // [Social-HIVE] Response error.
const int SocialHIVEInvalidParamSendMessage = -2000332;    // [Social-HIVE] Invalid parameter. Message content is required.
const int SocialHIVEInvalidParamSendInvitationMessage = -2000333;    // [Social-HIVE] Invalid parameter. Send invitation message.
const int SocialHIVEResponseFailGetPictureFromGallery = -2000334;    // [Social-HIVE] Response error. Failed to get picture from gallery.
const int SocialHIVEResponseFailGetPictureFromCamera = -2000335;    // [Social-HIVE] Response error. Failed to get picture from camera.
const int SocialHIVENetworkErrorSendInvitationMessage = -2000336;    // [Social-HIVE] Network error is occured on send invitation message.
const int PromotionNotInitialized = -3000001;    // [Promotion] Setup HIVE module first.
const int PromotionAlreadyShowing = -3000002;    // [Promotion] Promotion view already shown.
const int PromotionNetworkErrorShowCustomContents = -3000003;    // [Promotion] Network error occured on Show Custom Contents: %s
const int PromotionNetworkErrorShowOfferwall = -3000004;    // [Promotion] Network error occured on Show Offerwall
const int PromotionShowDialogFail = -3000005;    // [Promotion] Fail to show Dialog. Please check data from promotion server: %s
const int PromotionResponseFailGetViewInfo = -3000006;    // [Promotion] Response error. Failed to get view info
const int PromotionNetworkError = -3000007;    // [Promotion] Network error occured : %s
const int PromotionServerResponseError = -3000008;    // [Promotion] Server response error : %s
const int PromotionInvalidResponseData = -3000009;    // [Promotion] Invalid response data : %s
const int PromotionShareFailed = -3000010;    // [Promotion] Fail to share.
const int UserEngagementResponseFail = -3200001;    // [Promotion UE] Response error.
const int UserEngagementAlreadySetReady = -3200002;    // [Promotion UE] Already in ready to UE.
const int UserEngagementHandlerNotRegistered = -3200003;    // [Promotion UE] Handler not registered.
const int UserEngagementNotLogined = -3200004;    // [Promotion UE] Unauthorized User. Please do login first.
const int UserEngagementEmptyCouponId = -3200005;    // [Promotion UE] Coupon value is empty.
const int UserEngagementEmptyMarketPid = -3200006;    // [Promotion UE] Market pid value is empty.
const int UserEngagementListenerNotRegistered = -3200007;    // [Promotion UE] Listener is not registered.
const int PromotionStartPlayback = -3300001;    // [Promotion MV] Start playback.
const int PromotionFinishPlayback = -3300002;    // [Promotion MV] Finish playback.
const int PromotionYTPlayerError = -3300003;    // [Promotion MV] Youtube player get error : %s
const int PromotionCancelPlayback = -3300004;    // [Promotion MV] Cancel playback.
const int PushNotInitialized = -4000001;    // [Push] Setup HIVE module first.
const int PushInvalidParamLocalPush = -4000002;    // [Push] Invalid param : %s
const int PushInvalidParamRemotePush = -4000003;    // [Push] Invalid param : %s
const int PushNetworkError = -4000004;    // [Push] Network error occured : %s
const int PushAgeGateUnder13 = -4000005;    // [Push] Push can not use under 13 years old people because of age verification system.
const int PushInvalidResponseData = -4000006;    // [Push] Invalid response data : %s
const int PushServerResponseError = -4000007;    // [Push] Server response error : %s
const int PushNeedSignIn = -4000008;    // [Push] Need signin.
const int IAPNotInitialize = -6000001;    // [IAP] Not Initialized. Initialize User First.
const int IAPAlreadyInInitialize = -6000002;    // [IAP] Already IAP Initialized.
const int IAPNetworkError = -6000003;    // [IAP] Network error occured: %s
const int IAPNotSupportedMarket = -6000004;    // [IAP] Invalid or NOT supported market identifier. (%s)
const int IAPNeedLogin = -6000005;    // [IAP] Unauthorized User. Please do login first.
const int IAPNeedShopInitialize = -6000006;    // [IAP] Not Shop Initialized. Initialize Shop First.
const int IAPNotSupportedOSVersion = -6000007;    // [IAP] Unsupported OS Version.
const int IAPNeedRestore = -6000008;    // [IAP] Unfinished transactions: %s exists. Need restore.
const int IAPNothingToRestore = -6000010;    // [IAP] Nothing to restore.
const int IAPFailRestore = -6000011;    // [IAP] Fail to restore.
const int IAPRestrictPayments = -6000012;    // [IAP] This device is not able or allowed to make payments.
const int IAPNetworkJsonException = -6000013;    // [IAP] Json Exception during IAP Network
const int IAPMarketNotSupportedAPI = -6000014;    // [IAP] Market did not support this API
const int IAPFailMarketInitialize = -6000015;    // [IAP] Market data is nothing
const int IAPResponseError = -6000016;    // [IAP] Network response exception is occured.
const int IAPDialogActionDefault_DoExit = -6000017;    // [IAP] IAP Dialog Dismiss with unknown reason
const int IAPDialogActionOpenURL_DoExit = -6000018;    // [IAP] IAP Dialog Dismiss with OpenURL button selected
const int IAPDialogActionExit_DoExit = -6000019;    // [IAP] IAP Dialog Dismiss with Exit button selected
const int IAPDialogActionDone = -6000020;    // [IAP] IAP Dialog Dismiss with Done button selected
const int IAPDialogTimeover_DoExit = -6000021;    // [IAP] IAP Dialog Dismiss with Timeover
const int IAPInProgressPurchasing = -6000101;    // [IAP] Already in progress purchasing.
const int IAPInProgressRestoring = -6000102;    // [IAP] Already in progress restoring.
const int IAPInProgressCheckPromotePurchase = -6000103;    // [IAP] Already in progress check promote purchase.
const int IAPInProgressConnectingAppStore = -6000104;    // [IAP] Already in progress connecting App Store.
const int IAPInProgressMarketSelection = -6000105;    // [IAP] Already in progress market selection.
const int IAPAppStoreError = -6000201;    // [IAP] App Store Error: %s
const int IAPAppStoreResponseEmpty = -6000202;    // [IAP] Fail to get response data from App Store. Response data is empty.
const int IAPCannotFindGamePID = -6000301;    // [IAP] Can not find game pid matching with market pid, PID is empty or nil.
const int IAPProductNotExist = -6000302;    // [IAP] Can not find product in IAP Server: %s
const int IAPEmptyMarketPID = -6000303;    // [IAP] Fail to request purchase product. MarketPID is empty or nil.
const int IAPFailCreateSKPayment = -6000304;    // [IAP] SKPayment create failed.
const int IAPEmptyTransaction = -6000305;    // [IAP] Fail to request purchase. Purchased transaction is empty.
const int IAPEmptyProduct = -6000306;    // [IAP] Can not find market product using marker pid: %s
const int IAPCancelPayment = -6000307;    // [IAP] Failed to purchase(canceled): %s
const int IAPFailPayment = -6000308;    // [IAP] Failed to purchase
const int IAPInvalidMarketPID = -6000309;    // [IAP] Failed to convert to MarketPIDs to PID set.
const int IAPPurchaseParamJsonException = -6000310;    // [IAP] Purchase parameter json exception is occured.
const int IAPShopInfoParamJsonException = -6000311;    // [IAP] Shopinfo parameter json exception is occured.
const int IAPBadgeParamJsonException = -6000312;    // [IAP] Badge parameter json exception is occured.
const int IAPInvalidParamEmptyMarketPID = -6000401;    // [IAP] Game pid is empty.
const int IAPInvalidParamLocationCode = -6000402;    // [IAP] Location code is empty
const int IAPBlockedUser = -6000501;    // [IAP] This user has been blocked: %s
const int IAPPromoCodeMatchMultiMarketPID = -6000502;    // [IAP] Multiple product matched in market pid: %s
const int IAPPromoCodeNotMatchMarketPID = -6000503;    // [IAP] No product matched in market pid: %s
const int IAPPromoCodeAlreadyUsed = -6000504;    // [IAP] This Promotion code already used: %s
const int IAPAppleReceiptNotConnected = -6000505;    // [IAP] Apple receipt verifying server can not connected: %s
const int IAPServerDefaultError = -6000506;    // [IAP] IAP server error: %s
const int IAPInitializeMarketListIsEmpty = -6000601;    // [IAP] Resopnse failed. Market list is empty.
const int IAPInitializeMarketURLISEmpty = -6000602;    // [IAP] Resopnse failed. Market url is empty.
const int IAPEmptyMarketURL = -6000603;    // [IAP] Selected market URL is empty.
const int IAPNotSelectedMarket = -6000604;    // [IAP] Failed to select market.
const int IAPPlayStoreLaunchPurchaseFlowException = -6000701;    // [IAP] PlayStore launchpurchaseflow exception is occured.
const int IAPPlayStoreSetupFail = -6000702;    // [IAP] PlayStore start setup fail
const int IAPPlayStoreQueryInventoryFail = -6000703;    // [IAP] PlayStore query inventory fail when initialize
const int IAPPlayStorePending                              =  -6000704; // [IAP] PlayStore Billing state is pending.
const int IAPOneStoreProductListEmpty = -6000801;    // [IAP] OneStore Product List is empty.
const int IAPOneStoreProductNetworkError = -6000802;    // [IAP] OneStore requestProductInfo network fail
const int IAPOneStoreProductInfoError = -6000803;    // [IAP] OneStore requestProductInfo fail.
const int IAPOneStoreInvalidRequestID = -6000804;    // [IAP] OneStore requestID is invalid
const int IAPOneStorePurchaseError = -6000805;    // [IAP] OneStore purchase fail
const int IAPOneStoreNetworkNullError = -6000806;    // [IAP] Onestore Network response null error
const int IAPOneStoreNetworkInvalidError = -6000807;    // [IAP] Onestore Network response invalid error
const int IAPLebiInitializeNetworkError = -6000901;    // [IAP] Lebi Initialize fail
const int IAPLebiInitializeJsonException = -6000902;    // [IAP] Lebi initialize json exception is occured.
const int IAPLebiPurchaseNetworkError = -6000903;    // [IAP] Lebi purchase fail
const int IAPLebiPurchaseJsonException = -6000904;    // [IAP] Lebi purchase json exception is occured.
const int IAPLebiVerifyOrderNetworkError = -6000905;    // [IAP] Lebi verifyorder fail
const int IAPLebiVerifyOrderJsonException = -6000906;    // [IAP] Lebi verifyorder json exception is occured.
const int IAPLebiBalanceNetworkError = -6000907;    // [IAP] Lebi balance fail
const int IAPLebiBalanceParamJsonException = -6000908;    // [IAP] Lebi balance json exception is occured.
const int IAPLebiPostException = -6000909;    // [IAP] Lebi post exception is occured.
const int IAPLebiInternalRequestException = -6000910;    // [IAP] Lebi Internal request exception is occured.
const int IAPLebiRestoreNetworkError = -6000911;    // [IAP] Lebi restore create invalid response data
const int IAPV4NotInitialize = -6100001;    // [IAPv4] Setup HIVE module first.
const int IAPV4NetworkError = -6100002;    // [IAPv4] Network error occured: %s
const int IAPV4NotSupportedMarket = -6100003;    // [IAPv4] Market not supported.
const int IAPV4NeedSignIn = -6100004;    // [IAPv4] Unauthorized User. Please do sign in first.
const int IAPV4NeedMarketConnect = -6100005;    // [IAPv4] Shop not initialized. Initialize shop first.
const int IAPV4NeedRestore = -6100006;    // [IAPv4] Unfinished transactions: %s exists. Need restore.
const int IAPV4NothingToRestore = -6100007;    // [IAPv4] Nothing to restore.
const int IAPV4FailToRestore = -6100008;    // [IAPv4] Fail to restore.
const int IAPV4RestrictPayments = -6100009;    // [IAPv4] This device not able or allowed to make payments.
const int IAPV4FailMarketConnect = -6100010;    // [IAPv4] Invalid market data : %s
const int IAPV4ResponseError = -6100011;    // [IAPv4] Invalid response data : %s
const int IAPV4MarketNotSupportedAPI = -6100012;    // [IAPv4] Market did not support this API
const int IAPV4InProgressMarketConnect = -6100101;    // [IAPv4] Already in progress market connect.
const int IAPV4InProgressPurchasing = -6100102;    // [IAPv4] Already in progress purchasing.
const int IAPV4InProgressRestoring = -6100103;    // [IAPv4] Already in progress restoring.
const int IAPV4InProgressCheckPromote = -6100104;    // [IAPv4] Already in progress check promote purchase.
const int IAPV4InProgressConnectAppStore = -6100105;    // [IAPv4] Already in progress connect App Store.
const int IAPV4InProgressMarketSelect = -6100106;    // [IAPv4] Already in progress market select.
const int IAPV4AppStoreError = -6100201;    // [IAPv4] App store error: %s
const int IAPV4AppStoreResponseEmpty = -6100202;    // [IAPv4] Fail to get response data from App Store. Response data is empty.
const int IAPV4ProductNotExsitInAppStore = -6100203;    // [IAPv4] Can not find product: %s
const int IAPV4FinishMarketPidEmpty = -6100301;    // [IAPv4] Empty finished market PID.
const int IAPV4PromoteMarketPidEmpty = -6100302;    // [IAPv4] Empty market pid.
const int IAPV4FailCreateSKPayment = -6100303;    // [IAPv4] Fail to create payment.
const int IAPV4FailToConvertNSSet = -6100304;    // [IAPv4] Fail to conver to market pids to pid set.
const int IAPV4InvalidLogType = -6100305;    // [IAPv4] Invalid log type.
const int IAPV4ProductNotExist = -6100306;    // [IAPv4] Failed to request purchase product. Market product not found.
const int IAPV4RequestProductJsonException = -6100307;    // [IAPv4] Reqeust product json exception occured.
const int IAPV4PurchaseParamJsonException = -6100308;    // [IAPv4] Purchase parameter json exception occured.
const int IAPV4RequestMarketJsonException = -6100309;    // [IAPv4] Reqeust market json exception occured.
const int IAPV4ProductInfoJsonException = -6100310;    // [IAPv4] Product info json exception occured.
const int IAPV4CancelPayment = -6100311;    // [IAPv4] Failed to purchase(canceled)
const int IAPV4FailPayment = -6100312;    // [IAPv4] Failed to purchase
const int IAPV4EmptyParamMarketPID = -6100401;    // [IAPv4] Empty market pid.
const int IAPV4EmptyMarketList = -6100501;    // [IAPv4] Empty Market list from IAP server.
const int IAPV4EmptyMarketURL = -6100502;    // [IAPv4] Response failed. Market selection URL is emptry or nil.
const int IAPV4MarketPidListEmptyInIAPServer = -6100503;    // [IAPv4] Failed to request product indentifiers. MarketPID is empty or nil.
const int IAPV4EmptyProductList = -6100504;    // [IAPv4] IAP need get product info. get product info or showPayment API.
const int IAPV4ProductNotExistInIAPServer = -6100505;    // [IAPv4] Invalid parameter. Unknown market product identifier: %s
const int IAPV4PlayStoreLaunchPurchaseFlowException = -6100701;    // [IAPv4] PlayStore launchpurchaseflow exception occured.
const int IAPV4PlayStoreSetupFail = -6100702;    // [IAPv4] PlayStore start setup fail
const int IAPV4PlayStoreQueryInventoryFail = -6100703;    // [IAPv4] PlayStore query inventory fail when initialize
const int IAPV4PlayStoreFinishFail = -6100704;    // [IAPv4] PlayStore Finish fail.
const int IAPV4PlayStorePending = -6100705;    // [IAPv4] PlayStore Billing state is pending.
const int IAPV4OneStoreV5RemoteException = -6100801;    // [IAPv4] IAPV4OneStoreV5RemoteException
const int IAPV4OneStoreV5SecurityException = -6100802;    // [IAPv4] IAPV4OneStoreV5SecurityException
const int IAPV4OneStoreV5NeedUpdateException = -6100803;    // [IAPV4]OneStoreV5NeedUpdateException
const int IAPV4OneStoreCancelPayment = -6100804;    // [IAPV4] Cancel Payment
const int IAPV4OneStoreNetworkError = -6100805;    // [IAPV4] Can not connect to the OneStore
const int IAPV4OneStoreResponseError = -6100806;    // [IAPV4] Error response in OneStore
const int IAPV4OneStoreProductNotExist = -6100807;    // [IAPV4] Product not in sale
const int IAPV4OneStoreFailPayment = -6100808;    // [IAPV4] Failed to purchase
const int IAPV4OneStoreError = -6100809;    // [IAPV4] Error in OneStore %s
const int IAPV4OneStoreNeedRestore = -6100810;    // [IAPV4] Already owned the item
const int IAPV4OneStoreNothingToRestore = -6100811;    // [IAPV4] Did not owned the item
const int IAPV4OneStoreUnablePayment = -6100812;    // [IAPV4] Unable Payment. Check your credit.
const int IAPV4OneStoreNeedSignIn = -6100813;    // [IAPV4] Need OneStore signIn
const int IAPV4OneStoreException = -6100814;    // [IAPV4] Can not use OneStore
const int IAPV4OneStoreInvalidResponseData = -6100815;    // [IAPV4] Get invalid data from OneStore
const int IAPV4OneStoreInvalidParam = -6100816;    // [IAPV4] Invalid parameter.
const int IAPV4LebiInitializeNetworkError = -6100901;    // [IAPv4] Lebi Initialize fail
const int IAPV4LebiInitializeJsonException = -6100902;    // [IAPv4] Lebi initialize json exception occured.
const int IAPV4LebiPurchaseNetworkError = -6100903;    // [IAPv4] Lebi purchase fail
const int IAPV4LebiPurchaseJsonException = -6100904;    // [IAPv4] Lebi purchase json exception occured.
const int IAPV4LebiVerifyOrderNetworkError = -6100905;    // [IAPv4] Lebi verifyorder fail
const int IAPV4LebiVerifyOrderJsonException = -6100906;    // [IAPv4] Lebi verifyorder json exception is occured.
const int IAPV4LebiBalanceNetworkError = -6100907;    // [IAPv4] Lebi balance fail
const int IAPV4LebiBalanceParamJsonException = -6100908;    // [IAPv4] Lebi balance json exception is occured.
const int IAPV4LebiPostException = -6100909;    // [IAPv4] Lebi post exception is occured.
const int IAPV4LebiInternalRequestException = -6100910;    // [IAPv4] Lebi Internal request exception is occured.
const int IAPV4LebiRestoreNetworkError = -6100911;    // [IAPv4] Lebi restore create invalid response data
const int IAPV4LebiCancel = -6100912;    // [IAPv4] Lebi Charge cancel.
const int IAPV4LebiFinishFail = -6100913;    // [IAPv4] Lebi Finish fail.
const int IAPV4CancelMarketSelect = -6100914;    // [IAPv4] market select cancel.
const int IAPV4ServerResponseError = -6100915;    // [IAPv4] Server response error is occured. : %s
const int PlatformHelperOSNotSupported = -7000001;    // [PlatformHelper] %s is not supported.
const int PlatformHelperOSVersionNotSupported = -7000002;    // [PlatformHelper] %s OS version is not supported.
const int PlatformHelperEmptyPermissions                   =  -7000003;  // [PlatformHelper] Permissions is empty.
const int DataStoreNotExistKey                             =  -8000001; // [DataStore] Key is not exist.
const int DataStoreNotExistColumn                          =  -8000002; // [DataStore] Column Family(table) is not exist.
const int DataStoreNotExistPublicKey                       =  -8000003; // [DataStore] Public Key is not exist.
const int DataStoreNotInitialized                          =  -8000004; // [DataStore] Need Auth Setup.
const int DataStoreNeedSignIn                              =  -8000005; // [DataStore] Need Sign In.
const int DataStoreDisabled                                =  -8000006; // [DataStore] DataStore disabled.
const int DataStoreResponseError                           =  -8000007; // [DataStore] Server resposne error : %s
const int DataStoreInvalidParam                            =  -8000008; // [DataStore] Invalid parameter.///


#ifdef __cplusplus
};
#endif

#endif	// _C2SRESULT_API_H_
