#ifdef __ANDROID__
#include <string.h>
#include <jni.h>
#include "C2SMercury.h"

#include <malloc.h>

static JavaVM* g_vm;

static jobject g_obj;
static jclass userDefined;

MercuryCB g_MercuryCB = 0;
MercuryCBWithData g_MercuryCBWithData = 0;	// Add TH Jo 2015. 6 .11

JNIEXPORT void JNICALL
Java_com_com2us_module_mercury_Mercury_nativeMercuryInitialize(JNIEnv* env, jobject obj)
{
   (*env)->GetJavaVM(env, &g_vm);
    g_obj = (*env)->NewGlobalRef(env, obj);
    userDefined = (*env)->NewGlobalRef(env, (*env)->GetObjectClass(env,g_obj));
}

// apply to 64bit system
JNIEXPORT void JNICALL
Java_com_com2us_module_mercury_Mercury_nativeMercuryCallBack(JNIEnv* env, jobject obj, jlong callback)
{
	if(g_MercuryCB)
	{
		g_MercuryCB(callback);
	}
}

char* jstringToCharForMercury(JNIEnv* env, jstring str)
{
	char* cDesc = strdup( (*env)->GetStringUTFChars(env, str, 0) );
//	(*env)->ReleaseStringUTFChars(env, str, cDesc);
	return cDesc;
}

JNIEXPORT void JNICALL
Java_com_com2us_module_mercury_Mercury_nativeMercuryCallBackWithData(JNIEnv* env, jobject obj, jint result, jstring jsonData)
{
	if(g_MercuryCBWithData)
	{
		char *jsonDataString = jstringToCharForMercury(env, jsonData);
		g_MercuryCBWithData(result, jsonDataString);
		(*env)->ReleaseStringUTFChars(env, jsonData, jsonDataString);
	}
}

// apply to 64bit system
void CS_MercurySetCallBack(MercuryCB callback)
{
	g_MercuryCB = callback;

	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "setNativeCallBack", "(J)V");
		if(0 != method)
		{
			(*env)->CallVoidMethod(env, g_obj, method, callback);
		}
	}
}

void CS_MercuryShowEx(const char* uid, MERCURY_SHOW_TYPE mercuryShowType, const char* additionalInfo)
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryShowEx", "(Ljava/lang/String;ILjava/lang/String;)V");
		if(0 != method)
		{
			jint showType 	= (jint)mercuryShowType;
			jstring str 	= (*env)->NewStringUTF(env, uid);
			jstring str2	= (*env)->NewStringUTF(env, additionalInfo);

			(*env)->CallVoidMethod(env, g_obj, method, str, showType, str2);

			(*env)->DeleteLocalRef(env, str);
			(*env)->DeleteLocalRef(env, str2);
		}
	}
}

const char* CS_MercuryGetVersion() {
	JNIEnv *env = 0;
	jmethodID method;

	jstring jversion = 0;
	char *ret = "0";

	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **) &env, JNI_VERSION_1_6)) {
		method = (*env)->GetMethodID(env, userDefined, "getVersion", "()Ljava/lang/String;");
		if (0 != method) {
			jversion = (jstring) (*env)->CallObjectMethod(env, g_obj, method);
		}
	}

	if (jversion != 0) {
		ret = strdup((*env)->GetStringUTFChars(env, jversion, 0));
		(*env)->DeleteLocalRef(env, jversion);
		/* (ret == '\0') == (ret == NULL) == (ret == 0) */
		if (ret != NULL) {
			if (ret[0] == '\0') {
				free(ret);
				ret = 0;    /* or ret = NULL; */
			}
		}
	}

	return ret;
}

int CS_MercurySetBannerOnGameWindow(int isOn)
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "setBannerOnGameWindow", "(I)I");
		if(0 != method)
		{
			return (*env)->CallIntMethod(env, g_obj, method, isOn);
		}
	}
	return 0;
}

void CS_MercuryGetBadge(const int badgeForWhat)
{
	JNIEnv* env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryGetBadge", "(I)V");
		if(0 != method)
		{
			(*env)->CallVoidMethod(env, g_obj, method, badgeForWhat);
		}
	}
}

int CS_MercuryGetCustomViewInfo(const char* uid, const int viewID, MercuryCBWithData customViewCallback)
{
	g_MercuryCBWithData = customViewCallback;

	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryNativeGetCustomViewInfo", "(Ljava/lang/String;IJ)I");
		if(0 != method)
		{
			jstring str = (*env)->NewStringUTF(env, uid);
			jint customViewID = (jint)viewID;


			(*env)->CallIntMethod(env, g_obj, method, str, customViewID, customViewCallback);
			(*env)->DeleteLocalRef(env, str);
		}
	}

	return MERCURY_SUCCESS;

}

int CS_MercuryShowReviewPopup(const char* uid, const char* vid, const char* did)
{
	JNIEnv* env;
	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "showReviewPopup", "(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I");
		if(0 != method)
		{
			jstring strUid = (*env)->NewStringUTF(env, uid);
			jstring strVid = (*env)->NewStringUTF(env, vid);
			jstring strDid = (*env)->NewStringUTF(env, did);

			int retVal = (*env)->CallIntMethod(env, g_obj, method, strUid, strVid, strDid);

			(*env)->DeleteLocalRef(env, strUid);
			(*env)->DeleteLocalRef(env, strVid);
			(*env)->DeleteLocalRef(env, strDid);

			return retVal;
		}
	}
	return -1;
}

int CS_MercuryShowNativeReviewPopup(const char* uid, const char* vid, const char* did)
{
	JNIEnv* env;
	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "showNativeReviewPopup", "(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I");
		if(0 != method)
		{
			jstring strUid = (*env)->NewStringUTF(env, uid);
			jstring strVid = (*env)->NewStringUTF(env, vid);
			jstring strDid = (*env)->NewStringUTF(env, did);

			int retVal = (*env)->CallIntMethod(env, g_obj, method, strUid, strVid, strDid);

			(*env)->DeleteLocalRef(env, strUid);
			(*env)->DeleteLocalRef(env, strVid);
			(*env)->DeleteLocalRef(env, strDid);

			return retVal;
		}
	}
	return -1;
}

int CS_MercuryShowMoregamesPopup(const char* uid, const char* vid, const char* did)
{
	JNIEnv* env;
	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "showMoregamesPopup", "(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I");
		if(0 != method)
		{
			jstring strUid = (*env)->NewStringUTF(env, uid);
			jstring strVid = (*env)->NewStringUTF(env, vid);
			jstring strDid = (*env)->NewStringUTF(env, did);

			int retVal = (*env)->CallIntMethod(env, g_obj, method, strUid, strVid, strDid);

			(*env)->DeleteLocalRef(env, strUid);
			(*env)->DeleteLocalRef(env, strVid);
			(*env)->DeleteLocalRef(env, strDid);

			return retVal;
		}
	}
	return -1;
}

int CS_MercuryRequestUAInfo(const char* uid, const char* additionalInfo, MercuryCBWithData UAInfoCallback)
{
	g_MercuryCBWithData = UAInfoCallback;

	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryNativeRequestUAInfo", "(Ljava/lang/String;Ljava/lang/String;J)I");
		if(0 != method)
		{
			jstring strUid = (*env)->NewStringUTF(env, uid);
			jstring strAdditionalInfo = (*env)->NewStringUTF(env, additionalInfo);

			(*env)->CallIntMethod(env, g_obj, method, strUid, strAdditionalInfo, (jlong)UAInfoCallback);
			(*env)->DeleteLocalRef(env, strUid);
			(*env)->DeleteLocalRef(env, strAdditionalInfo);
		}
	}

	return MERCURY_SUCCESS;
}

int CS_MercuryGetBannerInfo(const char* campaignType, const char* bannerType, MercuryCBWithData bannerInfoCallback)
{
	g_MercuryCBWithData = bannerInfoCallback;

	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryNativeGetBannerInfo", "(Ljava/lang/String;Ljava/lang/String;J)I");
        if(0 != method)
        {
            jstring strCampaignType = (*env)->NewStringUTF(env, campaignType);
            jstring strBannerType = (*env)->NewStringUTF(env, bannerType);

            (*env)->CallIntMethod(env, g_obj, method, strCampaignType, strBannerType, (jlong)bannerInfoCallback);
            (*env)->DeleteLocalRef(env, strCampaignType);
            (*env)->DeleteLocalRef(env, strBannerType);
        }
	}

	return MERCURY_SUCCESS;
}

void CS_MercuryInitImageLoader()
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "initImageLoader", "()V");
		if(0 != method)
		{
			(*env)->CallVoidMethod(env, g_obj, method);
		}
	}
}

// apply to 64bit system
JNIEXPORT void JNICALL
Java_com_com2us_module_mercury_Mercury_jniRequestUAInfoNotifier(JNIEnv* env, jobject obj, jlong callbackPointer, jint result, jstring jsonData) {

    MercuryCBWithData cb = (MercuryCBWithData)callbackPointer;

    char* data = (jsonData == NULL) ? NULL : jstringToCharForMercury(env, jsonData);

    switch (result) {
        case MERCURY_SUCCESS:
            cb(MERCURY_SUCCESS, data);
            break;
        case MERCURY_FAILED:
            cb(MERCURY_FAILED, data);
            break;
        case MERCURY_INVALID_PARAM:
            cb(MERCURY_INVALID_PARAM, data);
            break;
        default:
            break;
    }

    if (data != NULL)
        (*env)->ReleaseStringUTFChars(env, jsonData, data);

}

int CS_MercuryRequestUALinkShare(const char* urlLink, const char* shareMessage)
{
	JNIEnv* env;
	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "mercuryRequestUALinkShare", "(Ljava/lang/String;Ljava/lang/String;)I");
		if(0 != method)
		{
			jstring strUrlLink = (*env)->NewStringUTF(env, urlLink);
			jstring strShareMessage = (*env)->NewStringUTF(env, shareMessage);

			int retVal = (*env)->CallIntMethod(env, g_obj, method, strUrlLink, strShareMessage);

			(*env)->DeleteLocalRef(env, strUrlLink);
			(*env)->DeleteLocalRef(env, strShareMessage);

			return retVal;
		}
	}
	return -1;
}

JNIEXPORT void JNICALL
Java_com_com2us_module_mercury_Mercury_jniRequestGetBannerInfoNotifier(JNIEnv* env, jobject obj, jlong callbackPointer, jint result, jstring jsonData) {

	MercuryCBWithData cb = (MercuryCBWithData)callbackPointer;

	char* data = (jsonData == NULL) ? NULL : jstringToCharForMercury(env, jsonData);

	switch (result) {
		case MERCURY_SUCCESS:
			cb(MERCURY_SUCCESS, data);
			break;
		case MERCURY_FAILED:
			cb(MERCURY_FAILED, data);
			break;
		case MERCURY_INVALID_PARAM:
			cb(MERCURY_INVALID_PARAM, data);
			break;
		default:
			break;
	}

	if (data != NULL)
	(*env)->ReleaseStringUTFChars(env, jsonData, data);
}
#endif
