#ifdef __ANDROID__
#include <string.h>
#include <jni.h>
#include "C2SOfferwall.h"

#include <malloc.h>

static JavaVM* g_vm;

static jobject g_obj;
static jclass userDefined;


char* jStringToChar(JNIEnv* env, jstring str)
{
	char* cDesc = strdup( (*env)->GetStringUTFChars(env, str, 0) );
//	(*env)->ReleaseStringUTFChars(env, str, cDesc);
	return cDesc;
}

JNIEXPORT void JNICALL
Java_com_com2us_module_offerwall_Offerwall_nativeOfferwallInitialize(JNIEnv* env, jobject obj)
{
   (*env)->GetJavaVM(env, &g_vm);
    g_obj = (*env)->NewGlobalRef(env, obj);
    userDefined = (*env)->NewGlobalRef(env, (*env)->GetObjectClass(env,g_obj));
}

// apply to 64bit system
JNIEXPORT void JNICALL
Java_com_com2us_module_offerwall_Offerwall_nativeOfferwallCallBack(JNIEnv* env, jobject obj, jlong callbackRef, jint callback)
{
	OfferwallCB offerwallCB = (OfferwallCB)callbackRef;

	if(offerwallCB)
	{
		offerwallCB(callback);
	}
}

// apply to 64bit system
void Java_com_com2us_module_offerwall_Offerwall_nativeOfferwallRewardCallBack(JNIEnv* env, jobject obj, jlong rewardCallbackRef,
		jint error, jstring errorMessage, jint result, jstring eventID, jstring assetCode, jint assetAmount)
{
	OfferwallRewardCB offerwallRewardCB = (OfferwallRewardCB)rewardCallbackRef;

	if(offerwallRewardCB)
	{
		char* _errorMessage = jStringToChar(env, errorMessage);
		char* _eventID 		= jStringToChar(env, eventID);;
		char* _assetCode	= jStringToChar(env, assetCode);
		offerwallRewardCB(error, _errorMessage, result, _eventID, _assetCode, assetAmount);
	}
}

// apply to 64bit system
void CS_OfferwallInitialize(const char* uid, int isUsingStaging, OfferwallCB callback)
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "nativeInitialize", "(Ljava/lang/String;IJ)V");
		if(0 != method)
		{
			jstring str = (*env)->NewStringUTF(env, uid);
			jlong callbackRef = (jlong)callback;
			(*env)->CallVoidMethod(env, g_obj, method, str, isUsingStaging, callbackRef);
		}
	}
}

// apply to 64bit system
void CS_OfferwallInitializeEx(const char* uid, int isUsingStaging, OfferwallCB offerwallCallback, OfferwallRewardCB rewardCallback)
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "nativeInitializeEx", "(Ljava/lang/String;IJJ)V");
		if(0 != method)
		{
			jstring str = (*env)->NewStringUTF(env, uid);
			jlong callbackRef = (jlong)offerwallCallback;			// offerwallCallback
			jlong offerwallCallbackRef = (jlong)rewardCallback;	    // rewardCallback
			(*env)->CallVoidMethod(env, g_obj, method, str, isUsingStaging, callbackRef, offerwallCallbackRef);
		}
	}
}

void CS_OfferwallShowEx(const char* additionalInfo)
{
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "showEx", "(Ljava/lang/String;)V");
		if(0 != method)
		{
			jstring str = (*env)->NewStringUTF(env, additionalInfo);
			(*env)->CallVoidMethod(env, g_obj, method, str);
			(*env)->DeleteLocalRef(env, str);
		}
	}
}

const char* CS_OfferwallGetVersion() {
	JNIEnv *env = 0;
	jmethodID method;

	jstring jversion = 0;
	char *ret = "0";

	if (JNI_OK == (*g_vm)->GetEnv(g_vm, (void **) &env, JNI_VERSION_1_6)) {
		method = (*env)->GetMethodID(env, userDefined, "getVersion", "()Ljava/lang/String;");
		if (0 != method) {
			jversion = (jstring) (*env)->CallObjectMethod(env, g_obj, method);
		}
	}

	if (jversion != 0) {
		ret = strdup((*env)->GetStringUTFChars(env, jversion, 0));
		(*env)->DeleteLocalRef(env, jversion);
		/* (ret == '\0') == (ret == NULL) == (ret == 0) */
		if (ret != NULL) {
			if (ret[0] == '\0') {
				free(ret);
				ret = 0;    /* or ret = NULL; */
			}
		}
	}

	return ret;
}

int CS_OfferwallGetState()
{
	int result = -1;
	JNIEnv*	env;
	if(JNI_OK == (*g_vm)->GetEnv(g_vm, (void **)&env, JNI_VERSION_1_6))
	{
		jmethodID method = (*env)->GetMethodID(env, userDefined, "getOfferwallState", "()I");
		if(0 != method)
		{
			result = (*env)->CallIntMethod(env, g_obj, method);
		}
	}
	return result;
}

#endif
