//
//  C2SActiveUser.h
//  ActiveUser
//
//  Created by Kim Inhong on 12. 3. 20..
//  Copyright (c) 2012년 Com2uS. All rights reserved.
//

#ifndef ActiveUser_C2SActiveUser_h
#define ActiveUser_C2SActiveUser_h
#ifdef __cplusplus
extern "C" {
#endif

    // UserAgree
    typedef enum USER_AGREE_TERMS
    {
        TERMS_GAME_SERVICE = 0,
        TERMS_PRIVACY,
        TERMS_SMS               // Android Only
    }USER_AGREE_TERMS_TYPE;

    typedef enum USER_AGREE_COLOR	// deprecated
    {
        USER_AGREE_COLOR_TYPE_WHITE = 0,
        USER_AGREE_COLOR_TYPE_BLACK = 1
    }USER_AGREE_COLOR_TYPE;

    // UserAgree Result Callback
    typedef enum USER_AGREE_RESULT_TYPE
    {
        USER_AGREE_SUCCESS = 0,
        USER_AGREE_TERMS_CLOSE = 1,
    }USER_AGREE_RESULT;

    typedef enum ACTIVR_USER_RESULT_TYPE
    {
        ACTIVE_USER_GETDID_SUCCESS = 0,
        ACTIVE_USER_GETDID_FAIL = 1,
    }ACTIVE_USER_RESULT;

    typedef enum SERVER_STATE_TYPE
    {
        LIVE_SERVER = 0,
        STAGING_SERVER = 1,
        SANDBOX_SERVER = 2
    }SERVER_STATE;
    
    typedef enum SHOW_POPUP_TYPE
    {
        SHOW = 0,
        NOTSHOW = 1,
		SHOW_POPUP_ERROR = -1
    }SHOW_POPUP;

    typedef enum POPUP_STATE_TYPE
    {
        CLOSE = 0,
		UNSHOWN = 1,
		POPUP_STATE_ERROR = -1
    }POPUP_STATE;

    typedef enum REQUEST_PERMISSION_STATE_TYPE    // Android Only
    {
        SUCCESS = 0,
        ERROR = -1,
        NOT_SUPPORT_OS_VERSION = -2,
        WRONG_TYPE_DATA = -3
    } REQUEST_PERMISSION_STATE;

    typedef enum MODULE_ORIENTATION_TYPE
    {
        ALL = 0,
        PORTRAIT = 1,
        LANDSCAPE = 2
    }MODULE_ORIENTATION;

    typedef void (*ActiveUserCB)(ACTIVE_USER_RESULT result);
    typedef void (*UserAgreeCB)(USER_AGREE_RESULT result);
    typedef void (*UpdateNoticePopupCB)(POPUP_STATE state);
    typedef void (*UpdateNoticeInfoCB)(SHOW_POPUP show, const char* jsonData);
    typedef void (*PermissionViewDataCB)(const char* jsonData);
    // Android Only
    typedef void (*RequestUserPermissionsCB)(REQUEST_PERMISSION_STATE state, const char* grantedPermissions, const char* deniedPermissions);

    void CS_ActiveUserSetCallback(ActiveUserCB cb);
    void CS_UserAgreeSetCallback(UserAgreeCB cb);
    
    
    // **** **** **** **** **** 
    // Active User Main API
    // **** **** **** **** **** 
    void CS_ActiveUserStart(void);
    void CS_ActiveUserStartEx(SERVER_STATE serverState);
    void CS_ActiveUserStartWithoutNotice(SERVER_STATE serverState, int showNoticePopup);
    void CS_ActiveUserSetServerId(const char* server_id);
    void CS_ActiveUserSetGameLanguage(const char* game_language);
    
    int CS_ActiveUserGetVersion(char* buf,int bufSize);
    void CS_ActiveUserUpdateServerId(const char* server_id);
    void CS_ActiveUserUpdateGameLanguage(const char* game_language);
    void CS_ActiveUserSetLogged(int isLogged);                          // Android Only
    const char* CS_ActiveUserGetDID(void);

    void CS_UpdateNoticeShowPopup(UpdateNoticePopupCB cb);              // 공지팝업 노출
    void CS_UpdateNoticeGetPopupInfo(UpdateNoticeInfoCB cb);            // 공지팝업 정보
    void CS_SetMinTimeoutSeconds(int seconds);                          // 네트워크 첫 타임아웃 시간 설정
    void CS_UserAgreeShowNoticeEx(void* parentView, void* contentsDict);
    void CS_ActiveUserGetPermissionViewData(PermissionViewDataCB cb);   // 권한 고지 정보 반환

    void CS_ActiveUserSetPermissionViewState(int isOn);                 // 권한 팝업 노출 여부 설정
    void CS_ActiveUserSendFunnelsLogs(const char* funnelsTrack, const char* optionTag);             // custom funnel 전송
    int CS_SetEmergencyModeWithUid(const char* uid);                    // 긴급로그인 모드 설정 
    void CS_ActiveUserRequestUserPermissions(const char* requests, RequestUserPermissionsCB cb);    // Android 권한 요청 기능 (Android Only)
    void CS_SetAnalyticsLogSettings(int sendLimit, int queueLimit, int sendCycleSecond);            // 애널리틱스 로그 전송 설정 기능

    void CS_UserAgreeShowTermsUI(void* parentView);
    void CS_UserAgreeShowTermsUIEx(void* parentView, const char* url);                              // 이용 약관 Custom URL
    int CS_SendAnalyticsLog(const char* logData);                       // 애널리틱스 로그 전송 기능
    void CS_SetModuleOrientation(MODULE_ORIENTATION orientation);       // ModuleOrientation 설정
    void CS_SetUseHercules(int enable);

    // +++++ +++++ +++++ +++++ +++++ 
    // Deprecated (removed)
    // +++++ +++++ +++++ +++++ +++++ 
    // void CS_ActiveUserSetVID(const char* vid) __deprecated_msg("Not support");
    // void CS_ActiveUserUseTestServer(void) __deprecated_msg("Not support");
    // void CS_ActiveUserRegisterToken(void* deviceToken) __deprecated_msg("2.8.3 Not support");       // iOS only
    // void CS_ActiveUserSetEnableRequestStoragePermission(void);                                      // Android only
    // void CS_UserAgreeReset(void) __deprecated_msg("Not support");

    // void CS_UserAgreeSetView(void* parentView) __deprecated_msg("Not support");                     // For Unity
    // void CS_UserAgreeShowUI(void* parentView) __deprecated_msg("Not support");                      // 콜백, 동의 페이지표시, deprecated in 2.2.0
    // void CS_UserAgreeShowUIEx(void* parentView, USER_AGREE_COLOR_TYPE colorType) __deprecated_msg("Not support");

#ifdef __cplusplus
};
#endif
#endif
